==> jool-4.0.5.tar.gz: jool-4.0.5/README.md <==
# [Jool](https://www.jool.mx)

An [SIIT and a NAT64](https://www.jool.mx/en/intro-xlat.html) for Linux.

> Note!
> 
> Jool's website is hosted in two separate domains simultaneously:
> 
> - https://www.jool.mx
> - https://nicmx.github.io/Jool

## Documentation

[See here](https://www.jool.mx/en/documentation.html). You can also [generate the docs yourself](docs/).

You might also want to see [contact info](https://www.jool.mx/en/contact.html).

## Credits

### NIC-Mx

* Ing. Jorge Cano Puente
* Ing. Sergio Adrián Casas Fernández - iam@sergio-casas.com
* Ing. Julio Cesar Cossio de Robles
* Ing. [Daniel Hernández Félix](https://github.com/dhfelix) - dhernandez@nic.mx
* Ing. [Alberto Leiva Popper](https://github.com/ydahhrk)
* Ing. Cristóbal Alfonso de León Benítez - cristobal.alfonso14@gmail.com
* Ing. Roberto Olivas Alarcón - roaguns@gmail.com
* Edgar Martín Rodríguez Bernal - edgarmrb_95@hotmail.com

### ITESM representatives

* Dr. Juan Arturo Nolazco - jnolazco@itesm.mx
* Ing. Martha Sordia - msordia@itesm.mx

### ITESM students

* [Abraham Baez](https://github.com/basuam) - basuam@gmail.com
* [Adrian González](https://github.com/Adrian2112) - bernardogzzf@gmail.com
* Alan Villela López - avillop@gmail.com
* [Angel Cazares](https://github.com/legionAngel) - angel.cazares@live.com
* Armando Cifuentes González - 3ncifuentesg@gmail.com
* [David Valenzuela](https://github.com/davidvrdz) - david.valenzuela.88@gmail.com
* Ing. Elvia Patricia Barrón Cano - epatybarron@gmail.com
* [Gabriel Chavez](https://github.com/chavezgu) - gabrielchavez02@gmail.com
* Jose Vicente Ramirez - pepermz@gmail.com
* [Juan Antonio Osorio](https://github.com/JAORMX) - jaosorior@gmail.com
* Juan Francisco Barragán Cantú - p.cantu12@gmail.com
* [Luis Fernando Hinojosa](https://github.com/luion) - lf.hinojosa@gmail.com
* Manuel Aude - dormam@gmail.com
* Mario Gerardo Trevinho - mario_tc88@hotmail.com
* [Miguel Alejandro González](https://github.com/magg) - maggonzz@gmail.com
* [Nixa Jayu Gpe Rodríguez Dagnino](https://github.com/NixaDagnino)
* [Ramiro Nava](https://github.com/ramironava) - ramironava@gmail.com
* [Roberto Aceves](https://github.com/robertoaceves) - roberto.aceves@gmail.com
* [Roberto Martínez Beltrán](https://github.com/ryuzak) - robmabe.92@gmail.com

### Special Thanks (contributing users)

* [airsnail](https://github.com/airsnail)
* [Andreas Urke](https://github.com/arurke)
* Andreas Rammhold
* [Dan Lüdtke](https://www.danrl.com)
* Eric Gamess
* [Hidekazu Tadokoro](https://github.com/tadokoro)
* [ipclouds](https://github.com/ipclouds)
* Jan Pokorny - FIT VUTBR
* [Masaya YAMAMOTO](https://github.com/pandax381)
* [Michael Richardson](http://www.sandelman.ca/mcr)
* [paradon](https://github.com/paradon)
* [Philar Law](https://github.com/philar)
* [Pier Carlo Chiodi](https://pierky.com/)
* [Ricardo Salveti](https://github.com/rsalveti) - ricardo@foundries.io
* [Sander Steffann](https://github.com/steffann) - sander@steffann.nl
* [Stanislav Bogatyrev](https://github.com/realloc)
* [tbe](https://github.com/tbe)
* [techmotive](https://github.com/techmotive)
* Terry Froy
* [Tore Anderson](https://github.com/toreanderson)
* Washam Fan

==> jool_4.1.2.orig.tar.gz: jool-4.1.2/README.md <==
# [Jool](https://www.jool.mx)

An [SIIT and a NAT64](https://www.jool.mx/en/intro-xlat.html) for Linux.

> Note!
> 
> Jool's website is hosted in two separate domains simultaneously:
> 
> - https://www.jool.mx (Might be outdated for a few days at a time)
> - https://nicmx.github.io/Jool (Unavailable from IPv6)

## Documentation

[See here](https://www.jool.mx/en/documentation.html). You can also [generate the docs yourself](docs/).

You might also want to see [contact info](https://www.jool.mx/en/contact.html).

## Credits

### NIC-Mx

* Ing. Jorge Cano Puente
* Ing. Sergio Adrián Casas Fernández - iam@sergio-casas.com
* Ing. Julio Cesar Cossio de Robles
* Ing. [Daniel Hernández Félix](https://github.com/dhfelix) - dhernandez@nic.mx
* Ing. [Alberto Leiva Popper](https://github.com/ydahhrk)
* Ing. Cristóbal Alfonso de León Benítez - cristobal.alfonso14@gmail.com
* Ing. Roberto Olivas Alarcón - roaguns@gmail.com
* Edgar Martín Rodríguez Bernal - edgarmrb_95@hotmail.com

### ITESM representatives

* Dr. Juan Arturo Nolazco - jnolazco@itesm.mx
* Ing. Martha Sordia - msordia@itesm.mx

### ITESM students

* [Abraham Baez](https://github.com/basuam) - basuam@gmail.com
* [Adrian González](https://github.com/Adrian2112) - bernardogzzf@gmail.com
* Alan Villela López - avillop@gmail.com
* [Angel Cazares](https://github.com/legionAngel) - angel.cazares@live.com
* Armando Cifuentes González - 3ncifuentesg@gmail.com
* [David Valenzuela](https://github.com/davidvrdz) - david.valenzuela.88@gmail.com
* Ing. Elvia Patricia Barrón Cano - epatybarron@gmail.com
* [Gabriel Chavez](https://github.com/chavezgu) - gabrielchavez02@gmail.com
* Jose Vicente Ramirez - pepermz@gmail.com
* [Juan Antonio Osorio](https://github.com/JAORMX) - jaosorior@gmail.com
* Juan Francisco Barragán Cantú - p.cantu12@gmail.com
* [Luis Fernando Hinojosa](https://github.com/luion) - lf.hinojosa@gmail.com
* Manuel Aude - dormam@gmail.com
* Mario Gerardo Trevinho - mario_tc88@hotmail.com
* [Miguel Alejandro González](https://github.com/magg) - maggonzz@gmail.com
* [Nixa Jayu Gpe Rodríguez Dagnino](https://github.com/NixaDagnino)
* [Ramiro Nava](https://github.com/ramironava) - ramironava@gmail.com
* [Roberto Aceves](https://github.com/robertoaceves) - roberto.aceves@gmail.com
* [Roberto Martínez Beltrán](https://github.com/ryuzak) - robmabe.92@gmail.com

### Special Thanks (contributing users)

* [airsnail](https://github.com/airsnail)
* [Andreas Urke](https://github.com/arurke)
* Andreas Rammhold
* [Dan Lüdtke](https://www.danrl.com)
* Eric Gamess
* [Hidekazu Tadokoro](https://github.com/tadokoro)
* [ipclouds](https://github.com/ipclouds)
* Jan Pokorny - FIT VUTBR
* [Masaya YAMAMOTO](https://github.com/pandax381)
* [Michael Richardson](http://www.sandelman.ca/mcr)
* [paradon](https://github.com/paradon)
* [Philar Law](https://github.com/philar)
* [Pier Carlo Chiodi](https://pierky.com/)
* [Ricardo Salveti](https://github.com/rsalveti) - ricardo@foundries.io
* [Sander Steffann](https://github.com/steffann) - sander@steffann.nl
* [Stanislav Bogatyrev](https://github.com/realloc)
* [tbe](https://github.com/tbe)
* [techmotive](https://github.com/techmotive)
* Terry Froy
* [Tore Anderson](https://github.com/toreanderson)
* Washam Fan
